@@ -32,11 +32,11 @@ Struct::Diff - Recursive diff for nested perl structures
 
 =head1 VERSION
 
-Version 0.97
+Version 0.98
 
 =cut
 
-our $VERSION = '0.97';
+our $VERSION = '0.98';
 
 =head1 SYNOPSIS
 
@@ -372,12 +372,18 @@ sub split_diff($) {
                 push @{$out{a}}, $sd->{a} if (exists $sd->{a});
                 push @{$out{b}}, $sd->{b} if (exists $sd->{b});
             }
+
+            $out{a} = [] unless (exists $out{a});
+            $out{b} = [] unless (exists $out{b});
         } else { # HASH
             for (keys %{$d->{D}}) {
                 $sd = split_diff($d->{D}->{$_});
                 $out{a}->{$_} = $sd->{a} if (exists $sd->{a});
                 $out{b}->{$_} = $sd->{b} if (exists $sd->{b});
             }
+
+            $out{a} = {} unless (exists $out{a});
+            $out{b} = {} unless (exists $out{b});
         }
     } elsif (exists $d->{U}) {
         $out{a} = $out{b} = $d->{U};
@@ -594,7 +600,7 @@ L<Data::Structure::Util>, L<Struct::Path>, L<Struct::Path::PerlStyle>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015-2018 Michael Samoglyadov.
+Copyright 2015-2019 Michael Samoglyadov.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
